/***************************************************************************
 *   Copyright (C) 2004-2005 by Andrew Krause                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "notebooktab.h"

// Initialize the objects for the new tab. This receives the short filename
// of the file to set the label to
void NotebookTab::initialize_objects(string filename)
{
  textview = gtk_source_view_new();
  swin = gtk_scrolled_window_new(NULL, NULL);
  label = gtk_label_new(filename.c_str());
  image = gtk_image_new_from_stock("gtk-close", GTK_ICON_SIZE_MENU);
  hbox = gtk_hbox_new(false, 0);
  button = gtk_button_new();
  
  set_object_properties();  
  show_all_objects();
}

// Set the properties of all of the objects in the tab.
void NotebookTab::set_object_properties()
{
  // Create the textview & add it to the scrolled window
  gtk_text_view_set_editable(GTK_TEXT_VIEW(textview), true);
  gtk_text_view_set_left_margin(GTK_TEXT_VIEW(textview), 2);
  GTK_WIDGET_SET_FLAGS(textview, GTK_CAN_FOCUS);
  gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(swin), GTK_SHADOW_IN);
  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(swin),
                                 GTK_POLICY_AUTOMATIC,
                                 GTK_POLICY_AUTOMATIC);
  gtk_container_add(GTK_CONTAINER(swin), textview);

  // Create the button & add the close image to it
  gtk_widget_set_size_request(button, 18, 18);
  gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
  gtk_container_add(GTK_CONTAINER(button), image);
	
  // Add the label and button the the tab hbox
  gtk_box_pack_start(GTK_BOX(hbox), label, false, false, 6);
  gtk_box_pack_start(GTK_BOX(hbox), button, false, false, 0);
}

// Show all of the objects in the tab.
void NotebookTab::show_all_objects()
{
  // Show all of the objects
  gtk_widget_show(textview);
  gtk_widget_show(swin);
  gtk_widget_show(label);
  gtk_widget_show(image);
  gtk_widget_show(hbox);
  gtk_widget_show(button);
}
